#!/bin/sh
# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77, 5698-B16
#
# Copyright IBM Corp. 2005,2009 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***
# Change History:
#
# mm/dd/yyyy userid    track     change history description here
# ---------- --------  -------   -----------------------------------------------
# 01/16/2009 jharter   d34001    Message Flows skipped on multiple enable/disable
# 05/27/2009 kevinjd  IZ51644    Loop more efficiently through mutliple broker flows
#=============================================================================
################## subroutine definitions ###############

general_syntax() {
    echo "Usage: $0 [-enable|-disable|-registerService|-deregisterService] -env [1|2|3|4|6|7|8|10] <server_specific_options>"
    echo "   Application server environments:"
    echo "      1 = IBM WebSphere Application Server (including WESB and Process Server)"
    echo "      3 = BEA WebLogic Application Server"
    echo "      4 = JBoss Application Server"
    echo "      6 = SAP NetWeaver Server"
    
    if [ "`uname`" = "Linux" ] 
   	then
    		echo "      7 = IBM Websphere Application Server Community Edition"
    fi
    
    echo "      8 = DataPower"
    echo "     10 = IBM WebSphere Message Broker"

    echo " -registerService and -deregisterService is applicable only for -env 8 ( DataPower ) "
    echo " registerService creates the KD4DPDCStartupCMD.sh in /etc/rc.d/init.d"

    rc=100;
}

find_KD4_home() {
    KD4_CONFIG="/etc/KD4BaseDirConfig.properties"
    if [ -f "$KD4_CONFIG" ]
    then
       . $KD4_CONFIG
       if [ -d "$INSTALLDIR" ]
       then
           echo "KD4 Home Dir = $INSTALLDIR"
           export INSTALLDIR
       else
           echo "Error: $INSTALLDIR not found" 
           rc=111
       fi
    else
        echo "Error: $KD4_CONFIG not found"
        rc=111
    fi
}

call_WAS_script()
{
    if [ ! "$ACTION" ] || [ "$ARG4" = "-h" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 1 (<WAS_HOME>)"
        rc=100;
    else
        if [ ! "$ARG4" ]
        then
            ARG4="USE_ENV_VAR"
        fi

        cmd="sh $INSTALLDIR/KD4/bin/configWASDC.sh $ACTION $ARG4" 
        echo "Configuration command = $cmd"
        sh $INSTALLDIR/KD4/bin/configWASDC.sh $ACTION "$ARG4"
        rc=$?
        echo "Return code from configWASDC.sh = $rc"
    fi
}

call_NET_script()
{
    OS=`uname`
    echo "Error:  Microsoft ASP.NET environment not supported on $OS"
    rc=114;
}

call_BEA_script()
{
    if [ ! "$ARG6" ] || [ "$ARG7" -a "$ARG7" != "-axis" ]
    then
        echo "Syntax: KD4configDC {-enable|-disable} -env 3 <URL> <userid> <password> [<type>]"
        echo    BEA WebLogic Application server configurations:
        echo    URL: The Web address of the BEA WebLogic Server.
        echo    userid: An valid WebLogic user name with the authority to configure applications.
        echo    password: A valid password associated with the specified WebLogic user name.
        echo    "type: The web service engine type. Specify -axis (without quotes) for Apache Axis "
        echo    Web service engine. If not specified, the regular BEA WebLogic Web service engine is used. 
        rc=100;
    else
        if [ ! "$ARG7" ]
	then
		cmd="sh $INSTALLDIR/KD4/bin/configBEADC.sh $ACTION $ARG4 $ARG5 $ARG6 $INSTALLDIR"
	else
		cmd="sh $INSTALLDIR/KD4/bin/configBEADC.sh $ACTION $ARG4 $ARG5 $ARG6 $INSTALLDIR $ARG7"
	fi
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configBEADC.sh = $rc"
    fi
}

# call the configDPDC.sh script.
call_DP_script()
{
   # min args: -action -env 8 -host hostName -user userName
 
   if [ ! "$ARG7" ] 
   then
      echo "Syntax: KD4configDC [-enable | -disable] -env 8 -host hostName -user userName (-pswd password -port port -path urlPath -poll pollInterval -domainlist \"domain1,domain2,...\" -displaygroup groupName)"
     echo
     echo "Usage: KD4configDC [-registerService|-deregisterService] -env 8"
      rc=100;
   else
        PROP_FILE=$INSTALLDIR/KD4/config/KD4.dpdcConfig.properties;

        # pull in the rest of the keys and values (4th arg to the end)
        KEY_VALUE_ARGS=`echo $ALL_ARGS | cut -f4- -d" "`

        cmd="sh $INSTALLDIR/KD4/bin/configDPDC.sh $ACTION $INSTALLDIR $PROP_FILE $KEY_VALUE_ARGS"
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configDPDC.sh = $rc"
    fi
      
}


# call configJBOSSDC.sh script
call_JBOSS_script()
{
    if [ ! "$ARG4" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 4 <server_name> <JBOSS_HOME>"
        echo "     server_name : Name of server to be configured"
	echo "     JBOSS_HOME : The path name where JBOSS is installed (optional). If the JBOSS_HOME environment variable has already been created, then it is not necessary to specify it as an input parameter."
        rc=100;
    else
    	if [ ! "$ARG5" ]
    	then 
    		echo $ARG5
    		ARG5="USE_ENV_HOME"
    		echo $ARG5
    	fi
        cmd="sh $INSTALLDIR/KD4/bin/configJBOSSDC.sh $ACTION $ARG4 $INSTALLDIR $ARG5"
        echo "Configuration command = $cmd"
        sh $INSTALLDIR/KD4/bin/configJBOSSDC.sh $ACTION $ARG4 $INSTALLDIR "$ARG5"
        rc=$?
        echo "Return code from configJBOSSDC.sh = $rc"
    fi
}
       
# CICS is not supported on distributed
cics_not_supported()
{
    OS=`uname`
    echo "Error:  CICS environment not supported on $OS"
    rc=114;
}

# call configWASCEDC.sh script
call_WASCEDC_script()
{
   OS_Name=`uname` 
   if [ "$OS_Name" != "Linux" ] 
   then
      echo "Error:  WASCE Data Collector cannot be enabled on $OS_Name. "
      echo "Only Windows and Linux are currently supported. "
      rc=100
   else
   if [ "$ARG4" = "-user" ]
   #if user doesn't input wasce home dir as parameter, just retrive environment variable $WASCE_HOME
   then
      ARG11=$ARG10
      ARG10=$ARG9
      ARG9=$ARG8
      ARG8=$ARG7
      ARG7=$ARG6
      ARG6=$ARG5
      ARG5=$ARG4
      ARG4=$WASCE_HOME
      NUM_ARG=`expr $NUM_ARG + 1`
   fi
   echo "arg4=$ARG4"

   if [ "$NUM_ARG" -eq "10" ]
   then
      if [ ! "$ARG6" ] || [ ! "$ARG8" ] || [ "$ARG5" != "-user" ] || [ "$ARG7" != "-passwd" ] || [ "$ARG9" != "-file" ]
      then
         call_WASCE_syntax
      else
         #if user just input -file only ,pass $ARG10 which is filename
         cmd="sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION $ARG4 $ARG6 $ARG8 $INSTALLDIR $ARG10"
	 echo "Configuration command = $cmd"
	 sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION "$ARG4" $ARG6 $ARG8 "$INSTALLDIR" "$ARG10"
	 rc=$?
	 echo "Return code from configWASCEDC.sh = $rc"
      fi
   elif [ "$NUM_ARG" -eq "11" ]
   then
      if [ ! "$ARG6" ] || [ ! "$ARG8" ] || [ "$ARG5" != "-user" ] || [ "$ARG7" != "-passwd" ] || [ "$ARG9" != "-list" ] || [ "$ARG10" != "-file" ]
      then
         call_WASCE_syntax
      else
         #if user input -list -file, pass $ARG11 which is filename and $ARG9 which is -list
         cmd="sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION $ARG4 $ARG6 $ARG8 $INSTALLDIR $ARG11 $ARG9"
         echo "Configuration command = $cmd"
         sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION "$ARG4" $ARG6 $ARG8 "$INSTALLDIR" "$ARG11" $ARG9
	 rc=$?
	 echo "Return code from configWASCEDC.sh = $rc"
      fi        	
   else
      call_WASCE_syntax
   fi				
   fi
}

# call configSAPDC.sh script
call_SAP_script()
{
    if [ ! "$ARG4" ] || [ ! "$ARG5" ] 
    then
        call_SAP_syntax;
        echo ""
        echo ""
        rc=201
        echo "Return code = $rc"
    else

    	if  [ "$ARG4" != "-sapappsdir" ] && [ "$ARG4" != "-clientappsdir" ] && [ "$ARG4" != "-sid" ] 
    	then 
                call_SAP_syntax;
                echo ""
                echo ""
                rc=201
                echo "Return code = $rc"
    	else
		if  [ "$ARG4" = "-sapappsdir" ] &&  [ "$NUM_ARG" = "5" ] 
        	then
			cmd="sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 \"$ARG5\""
			echo "Configuration command = $cmd"
			sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 "$ARG5"
			rc=$?
		elif [ "$ARG4" = "-clientappsdir" ] && [ "$NUM_ARG" = "5" ] 
		then
			cmd="sh $INSTALLDIR/KD4/bin/configSAPClientDC.sh $ACTION $ARG4 \"$ARG5\""
			echo "Configuration command = $cmd"
			sh $INSTALLDIR/KD4/bin/configSAPClientDC.sh $ACTION $ARG4 "$ARG5"
			rc=$? 
		elif [ "$ARG4" = "-sid" ] && [ "$NUM_ARG" = "6" ] 
		then 
			cmd="sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 $ARG5 \"$ARG6\""
			echo "Configuration command = $cmd"
			sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 $ARG5 "$ARG6" 
			rc=$?
		else
			call_SAP_syntax;
               	 	echo ""
                	echo ""
                	rc=201
                	echo "Return code = $rc"
		        return

		fi
        	        	
		if  [ "$ARG4" = "-sapappsdir"  ]  || [ "$ARG4" = "-sid" ]  
        	then
			echo "Return code from configSAPDC.sh = $rc"
		else
			echo "Return code from configSAPClientDC.sh = $rc"
		fi				
    	fi
    fi
}

call_WASCE_syntax(){
   echo "Syntax: KD4configDC [-enable|-disable] -env 7 <WASCE_HOME>  -user {user_name} -passwd {passwd} [-list] -file <filename>"
   echo "     WASCE_HOME :  The path name where WASCE is installed (optional). If the WASCE_HOME environment variable is already created, it is not necessary to specify it as an input parameter."
   echo "     user_name  :  WASCE administrator user ID"
   echo "     passwd     :  a valid password for the specified administrator user ID"
   echo "     -list      :  Used for generating applications list file only"	
   echo "     filename   :  The file name, relative to the current directory, that contains the list of applications"
   echo ""
   echo ""
   rc=190
   echo "Return code = $rc"   
}

call_SAP_syntax(){
echo "KD4CF0051W Before running this utility, refer to the documentation for details about enabling applications in the SAP NetWeaver environment."
}


#************************************************************************************
# call configMBDC.sh script
#************************************************************************************
call_MB_script()
{         
	if [ ! -d "${INSTALLDIR}/KD4/config/wmb" ]
	then
		mkdir -p "${INSTALLDIR}/KD4/config/wmb"
		chmod 777 "${INSTALLDIR}/KD4/config/wmb"
	fi
	
	if [ ! -d "${INSTALLDIR}/KD4/config/wmb/lib" ]
	then
		mkdir -p "${INSTALLDIR}/KD4/config/wmb/lib"
		chmod 777 "${INSTALLDIR}/KD4/config/wmb/lib"
	fi
	
	if [ ! -d "${INSTALLDIR}/KD4/config/wmb/config" ]
	then
		mkdir -p "${INSTALLDIR}/KD4/config/wmb/config"
		chmod 777 "${INSTALLDIR}/KD4/config/wmb/config"
	fi

    if [ -f $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running ]
    then
       echo "";
       echo "Error: There might be another instance of the script running on the same broker."
       echo "If you are sure that there is no other instance running, remove the file:"
       echo "$INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running file, then run it again."
       rc=196
       echo ""; echo "Return code = $rc"
       sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh WMB_CONCURRENT_ACTION $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running
    else
       OS_NAME=`uname`
       if [ "$OS_NAME" = "Linux" -o "$OS_NAME" = "AIX" -o "$OS_NAME" = "HP-UX" -o "$OS_NAME" = "SunOS" ]
       then
          #************************************************************************************
          #UNIX/LINUX platform
          #************************************************************************************          
          if [ "$NUM_ARG" -lt "6" ]
          then
              call_MB_syntax;
          else
             LIST_OF_FLOWS=$ARG6
             shift
             while [ "$6" ] ;
             do
                LIST_OF_FLOWS="${LIST_OF_FLOWS} $6"
                shift
             done
                 

              cmd="sh $INSTALLDIR/KD4/bin/configMBDC.sh $ACTION \"$ARG4\" \"$ARG5\" \"$LIST_OF_FLOWS\""
              echo "Configuration command = $cmd"
                            
              echo "***************************************************************************"
              echo "NOTE: The Message Broker will be stopped to enable or disable some configuration."
              echo "If you do NOT want to continue, press CTRL+C, otherwise press Enter to continue."
              echo "***************************************************************************"
              echo "Press Enter key to continue . . ."
              if [ "$errorFile" = "" ]
              then 
                  read contine_key
              fi
              
              if [ -f $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running ]
              then
                 echo "";
                 echo "Error: There might be another instance of the script running on the same broker."
                 echo "If you are sure that there is no other instance running, remove the file:"
                 echo "$INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running file, then run it again."
                 rc=196
                 echo ""; echo "Return code = $rc"
                 sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh WMB_CONCURRENT_ACTION $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running
              else       
                 touch $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running 1>>/dev/null 2>>/dev/null
                 chmod 777 $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running 1>>/dev/null 2>>/dev/null

 	         cmd="sh $INSTALLDIR/KD4/bin/configMBDC.sh $ACTION \"$ARG4\" \"$ARG5\" \"$LIST_OF_FLOWS\""
 	         echo "Configuration command = $cmd"
                 echo "Processing Message Flow: $LIST_OF_FLOWS"
                 sh $INSTALLDIR/KD4/bin/configMBDC.sh $ACTION "$ARG4" "$ARG5" "$LIST_OF_FLOWS"
                 rc=$?
                 echo "Return code from configMBDC.sh = $rc"
                 shift	                 
                 ARG6=$6

              fi
          fi
       elif [ "$OS_NAME" = "OS/390" ]
       then
          #************************************************************************************
          #ZOS platform
          #************************************************************************************
          if [ "$NUM_ARG" -ne "4" ]
          then
             call_MB_syntax_ZOS;
          else
              cmd="sh $INSTALLDIR/KD4/bin/configMBDC.sh $ACTION \"$ARG4\""
              echo "Configuration command = $cmd"
              
              echo "***************************************************************************"
              echo "NOTE: Some settings need to be changed to enable or disable some Message"
              echo "Broker configuration. If you do NOT want to continue, Press CTRL+C,"
              echo "otherwise press Enter to continue."
              echo "***************************************************************************"
              echo "Press Enter key to continue . . ."
              read contine_key
              
              touch $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running 1>>/dev/null 2>>/dev/null
              chmod 777 $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running 1>>/dev/null 2>>/dev/null
              
              sh $INSTALLDIR/KD4/bin/configMBDC.sh $ACTION "$ARG4"
              rc=$?
              echo "Return code from configMBDC.sh = $rc"
          fi
       else
          echo ""; echo "Current OS `uname`.  It is not supported." ; echo ""
       fi
       
       rm -f $INSTALLDIR/KD4/config/wmb/config/configMBDC_$ARG4.running 1>>/dev/null 2>>/dev/null
    fi
}

call_MB_syntax(){
   echo ""
   echo "Usage: ./KD4configDC.sh {-enable |-disable} -env 10 Broker_name \
 Execution_group_name Message_flow_list"
   echo ""
   echo "Broker_name: The name of broker to be configured"
   echo ""
   echo "Execution_group_name: The name of execution group to be configured"
   echo ""
   echo "Message_flow_list: The list of message flow names to be configured"
   echo ""
   echo "Example 1: ./KD4configDC.sh -enable  -env 10 BRK wshgrp WSHOST_MFP1.WSHOST_WSHOST1 Flow2 Flow3"
   echo ""
   echo "Example 2: ./KD4configDC.sh -disable -env 10 BRK wshgrp WSHOST_MFP1.WSHOST_WSHOST1 Flow2 Flow3"
   echo ""
   echo ""
   rc=191
   echo "Return code = $rc"   
}

call_MB_syntax_ZOS(){
   echo "Usage: ./KD4configDC.sh {-enable |-disable} -env 10 Broker_name"
   echo ""
   echo "Broker_name: The name of broker to be configured"
   echo ""
   echo "Example 1: ./KD4configDC.sh -enable  -env 10 BRK"
   echo ""
   echo "Example 2: ./KD4configDC.sh -disable -env 10 BRK"
   echo ""
   echo ""
   rc=191
   echo "Return code = $rc"   
}
#
# Datapower Registration as Daemon Process for Unix systems
#
call_set_DP_DC_RegisterDaemon_INITDIR_RCDIR(){
   # If any changes are being made to the if conditions in this
   # routine, please fix in call_DP_DC_DeRegister_Daemon too
   OS=`uname` 
    #
    # AIX does not have /etc/init.d file
    #
    if [ "$OS" = "AIX" ]
    then
       INITDIR=/etc/rc.d/init.d
       RCDIR=/etc/rc.d/rc2.d
    fi
    #
    # Sun rc3.d is in /etc/rc3.d
    #
    if [ "$OS" = "SunOS" ]
    then
      INITDIR=/etc/init.d
      RCDIR=/etc/rc3.d
    fi
    #
    # Linux rc3.d is in /etc/rc.d/rc3.d
    #
    if [ "$OS" = "Linux" ]
    then
      INITDIR=/etc/init.d
      RCDIR="/etc/rc.d/rc3.d /etc/rc.d/rc5.d"
      STOPRCDIR=/etc/rc.d/rc0.d
    fi 
    #
    # HP UX init.d is in /sbin/
    #
    if [ "$OS" = "HP-UX" ]
    then
      INITDIR=/sbin/init.d
      RCDIR=/sbin/rc3.d
    fi
}
call_DP_DC_Register_Daemon(){
    call_set_DP_DC_RegisterDaemon_INITDIR_RCDIR
    if [ -f $INITDIR/KD4DPDCStartup.sh ]
    then
      echo "IBM Tivoli Composite Application Manager for SOA, DataPower Data Collector is already enabled for auto start"
      sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh DPDC_ALREADY_REGISTERED
      exit 186
    fi
    cp $INSTALLDIR/KD4/bin/KD4DPDCStartup.sh $INITDIR/KD4DPDCStartup.sh
    RCVAL=$?
    if [ $RCVAL -ne 0 ]
    then
      sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh UNABLE_TO_COPY_FOR_SYSTEM_RESTART KD4DPDCStartup.sh $INITDIR
      exit 187
    fi
    chmod +x $INITDIR/KD4DPDCStartup.sh
    for i in `echo $RCDIR`
    do
       ln -s $INITDIR/KD4DPDCStartup.sh $i/S99KD4DPDCStartup
       ln -s $INITDIR/KD4DPDCStartup.sh $i/K99KD4DPDCStartup
    done
    if [ ! -z "$STOPRCDIR" ]
    then
       ln -s $INITDIR/KD4DPDCStartup.sh $STOPRCDIR/K99KD4DPDCStartup
    fi
}

call_DP_DC_DeRegister_Daemon(){
   call_set_DP_DC_RegisterDaemon_INITDIR_RCDIR
   if [ ! -f $INITDIR/KD4DPDCStartup.sh ] 
   then
     echo "IBM Tivoli Composite Application Manager for SOA, DataPower Data Collector is not enabled for auto start"
     sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh DPDC_NOT_REGISTERED_AS_DAEMON
     exit 188
   fi
   for i in `echo $RCDIR`
   do
      rm $i/S99KD4DPDCStartup
      RCVAL=$?
      if [ $RCVAL -ne 0 ]
      then
        sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh UNABLE_TO_REMOVE_FILE_FOR_DP_REGISTER S99KD4DPDCStartup $i
        exit 189
      fi
      rm $i/K99KD4DPDCStartup
   done
   if [ ! -z "$STOPRCDIR" ]
   then
      rm $STOPRCDIR/K99KD4DPDCStartup
   fi
   rm $INITDIR/KD4DPDCStartup.sh
}
#************************************************************************************

######################## mainline ######################

################ set parameters for ISMP ###############
# backup env variable
old_errorFile=$errorFile
errorFile=
export errorFile
export old_errorFile
old_JVM_PARAMETER=$JVM_PARAMETER
JVM_PARAMETER=
export JVM_PARAMETER
export old_JVM_PARAMETER
# set parameters
if [ "$1" = "-errorFile" ]
then
    errorFile=$2
    export errorFile
    JVM_PARAMETER=-DerrorFileForISMP=$errorFile
    export JVM_PARAMETER
    shift
    shift
fi
# End of for ISMP
#########################################################


ACTION=$1
ENV_KEY=$2
ENV_TYPE=$3
ARG4=$4
ARG5=$5
ARG6=$6
ARG7=$7
ARG8=$8
ARG9=$9
ALL_ARGS=$*
NUM_ARG=$#

# D34001
# If this is for the WASCE environment, check for a 10th
# or 11th parameter.  Do not do this for other environments
# (like WMB) or parameters will be lost on the shift.
if [ "$ENV_TYPE" -eq "7" ]
then 
   if [ "$NUM_ARG" -eq "10" ]
   then
       shift
       ARG10=$9
       ARG11=""
   elif [ "$NUM_ARG" -eq "11" ]
   then
       shift
       shift
       ARG10=$8
       ARG11=$9
   else
       ARG10=""
       ARG11=""
   fi
fi

rc=0;

if [ "$ENV_KEY" != "-env" ] 
then
   general_syntax 
   exit $rc
fi  

if [ "$ACTION" != "-enable" ] && [ "$ACTION" != "-disable" ] && [ "$ACTION" != "-registerService" ] && [ "$ACTION" != "-deregisterService" ]
then
   general_syntax 
   exit $rc
fi  

if [ "$ACTION" = "-registerService" ] || [ "$ACTION" = "-deregisterService" ]  && [ $ENV_TYPE != 8 ]
then
   general_syntax 
   exit $rc
fi

find_KD4_home

if [ "$ACTION" = "-registerService" ] 
then
  call_DP_DC_Register_Daemon
  exit 0
fi
if [ "$ACTION" = "-deregisterService" ] 
then
  call_DP_DC_DeRegister_Daemon
  exit 0
fi
case $ENV_TYPE in
    1) call_WAS_script ;;
    2) call_NET_script ;;
    3) call_BEA_script ;;
    4) call_JBOSS_script ;;      
    5) cics_not_supported;;
    6) call_SAP_script ;;
    7) call_WASCEDC_script ;;
    8) call_DP_script ;;
    9) general_syntax ;;
   10) call_MB_script $* ;;
    *) general_syntax ;;
esac

exit $rc;
