#!/bin/sh
# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77
#
# Copyright IBM Corp. 2005,2006,2007 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***
# Change History:
#
# mm/dd/yyyy userid    track     change history description here
# ---------- --------  -------   -----------------------------------------------
# 11/09/2006 JXL                 Create
# 12/26/2006 chenff    f21153    Modify
# 02/12/2007 chenff    f22090    modify configMBDC.bat and configMBDC.sh for defect 22052, 
#                                The defect is that RC=0 when enable MBDC with non-exist flow
#                                add check variables about BROKER_NAME, 
#                                EXECUTION_GROUP_NAME and MESSAGE_FLOW_NAME 
# 02/13/2007 chenff    f22052    The same as 22090 feature.
# 03/20/2007 chenff    f22942    Avoid KD4configDC be run on same broker with multiple instances
# 03/29/2007 chenff    d23316    Add cp command -f option.
# 04/03/2007 chenff    d23103f_1 Some issures with MBDC configuation script
#                                and add DEBUG_LOG method
# 04/04/2007 chenff    d23172    Add return code as below
#                                197 Message Flow MESSAGE_FLOW_NAME has been enabled.
#                                198 Message Flow MESSAGE_FLOW_NAME has not ever been enabled. 
# 04/12/2007 chenff    d23944    Modify prompt message
# 04/17/2007 chenff    d24003    Message Broker was still restarted when enable/disable a non-exist message flow.
#                                The script should check the message flow first,
#                                it is no need to restart MB if the message flow doesn't exist.
# 04/26/2007 chenff    d24306    lel file will is not deleted after un-installation
# 04/26/2007 chenff    d24210    Modify prompt message
# 06/07/2007 chenff    f26085    Modify enable-disable scripts to support SunOS and HP-UX
# 09/11/2007 chenff    d29284    Change the created directories and files modes.  As following: use command 'chmode 777'
# 05/27/2009 kevinjd   IZ51644   Optimize to minimize broker downtime
#=============================================================================


DEBUG_LOG()
{
   echo `date "+%Y-%m-%d %H:%M:%S"` $* >> $KD4_LOGDIR/configMBDC.log
}

MBDC_MKDIR()
{
   if [ "$1" != "" ]
   then
      if [ ! -d "$1" ]
      then
         DEBUG_LOG mkdir -p "$1"    
         mkdir -p "$1" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
         DEBUG_LOG chmod 777 "$1"
         chmod 777 "$1" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
      fi
   fi
}

MBDC_RM_DIR()
{
   if [ "$1" != "" ]
   then
      if [ -d "$1" ]
      then
         DEBUG_LOG rm -rf "$1"    
         rm -rf "$1" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
      fi
   fi
}

MBDC_TOUCH()
{
   if [ "$1" != "" ]
   then
      if [ ! -f "$1" ]
      then
         DEBUG_LOG touch "$1"    
         touch "$1" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
         DEBUG_LOG chmod 777 "$1"
         chmod 777 "$1" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
      fi
   fi
}

MBDC_RM_FILE()
{
   if [ "$1" != "" ]
   then
      if [ -f "$1" ]
      then
         DEBUG_LOG rm -f "$1"    
         rm -f "$1" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
      fi
   fi
}

MBDC_ChangeUserExitPath()
{
   #***************************************************************************
   #change broker user exit path(s)
   #***************************************************************************
   DEBUG_LOG "Change broker user exit path..."
 
# IZ51644 Main logic will control stops and starts
#   DEBUG_LOG mqsistop "$BROKER_NAME"
#   mqsistop "$BROKER_NAME" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
   
   if [ "$ACTION" = "-enable" ]
   then
      DEBUG_LOG cp -f "$INSTALLDIR/KD4/lib/$LEL_NAME" "$SOA_EXIT_PATH/$LEL_NAME"
      cp -f "$INSTALLDIR/KD4/lib/$LEL_NAME" "$SOA_EXIT_PATH/$LEL_NAME" 1>>$KD4_LOGDIR/configMBDC.log
      chmod 777 "$SOA_EXIT_PATH/$LEL_NAME" 1>>$KD4_LOGDIR/configMBDC.log
   fi
   
   DEBUG_LOG mqsichangebroker "$BROKER_NAME" -x "$1"
   mqsichangebroker "$BROKER_NAME" -x "$1" 1>>$KD4_LOGDIR/configMBDC.log 
}
 
#***************************************************************************
#** Validate $BROKER_NAME, $EXECUTION_GROUP_NAME, and $MESSAGE_FLOW_NAME
#***************************************************************************
validateParms()
{   
   # Validate the $Action var
   if [ $ACTION != "-enable" ]
   then
      if [ $ACTION != "-disable" ]
      then
         echo Error: $ACTION is not [-enable|-disable]
         DEBUG_LOG Error: $ACTION is not [-enable|-disable]
         RC=191
         sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh MB_ACTION_ERROR $ACTION
         exit $RC
      fi
    fi
   
   #***************************************************************************
   #start broker
   #***************************************************************************
   #echo "mqsistart ${BROKER_NAME}"
   DEBUG_LOG "mqsistart ${BROKER_NAME}"
   mqsistart "$BROKER_NAME" 1>>${KD4_LOGDIR}/configMBDC.log 
   RC=$?
   
   # Error if the 'mqsistart' command could not be found
   if [ $RC -eq 127 ]   # not found
   then
      echo Error: The MQSI command-line environment is not ready.  
      DEBUG_LOG Error: The MQSI command-line environment is not ready.
      exit $RC
   fi  
      
   #***************************************************************************
   #This part is to check variables
   #BROKER_NAME
   #EXECUTION_GROUP_NAME
   #MESSAGE_FLOW_NAME
   #***************************************************************************
   DEBUG_LOG Checking if broker $BROKER_NAME exists
   DEBUG_LOG mqsireportflowuserexits $BROKER_NAME \| grep BIP8071I
   mqsireportflowuserexits $BROKER_NAME | grep BIP8071I 1>>${KD4_LOGDIR}/configMBDC.log
   RC=$?
   if [ $RC -ne 0 ]
   then
      echo Error: Broker $BROKER_NAME does not exist.
      DEBUG_LOG Error: Broker $BROKER_NAME does not exist.
      RC=192
      rm -rf ${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
      rm -rf ${INSTALLDIR}/KD4/config/wmb/config/$BROKER_NAME 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
      sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh MB_HOME_ERROR $BROKER_NAME
      exit $RC
   fi
   
   DEBUG_LOG Checking if execution group $EXECUTION_GROUP_NAME exists
   DEBUG_LOG mqsireportflowuserexits $BROKER_NAME -e $EXECUTION_GROUP_NAME \| grep BIP8071I
   mqsireportflowuserexits $BROKER_NAME -e $EXECUTION_GROUP_NAME | grep BIP8071I 1>>${KD4_LOGDIR}/configMBDC.log
   RC=$?
   if [ $RC -ne 0 ]
   then
      echo Error: Execution Group $EXECUTION_GROUP_NAME does not exist.
      DEBUG_LOG Error: Execution Group $EXECUTION_GROUP_NAME does not exist.
      RC=193
      sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh MB_EXECUTION_GROUP_ERROR $EXECUTION_GROUP_NAME
      exit $RC
   fi
   
   # IZ51644 use mqsilist and make sure you get a BIP813I message for each flow
   DEBUG_LOG Checking if message flows exist
   DEBUG_LOG mqsilist $BROKER_NAME -e $EXECUTION_GROUP_NAME | grep BIP8131I | awk '{print $3}'
   LIST_OF_FLOWS=`mqsilist $BROKER_NAME -e $EXECUTION_GROUP_NAME | grep BIP8131I | awk '{print $3}'`
   echo The following flows exist on this execution group: ${LIST_OF_FLOWS}1>>${KD4_LOGDIR}/configMBDC.log
   
   # The echo is necessary for the "for" loop to parse correctly.
   ARG_LIST=`echo ${MESSAGE_FLOW_NAME}`
   ARG_COUNT=`echo ${ARG_LIST} | wc -w`
  
   # 36077.1 Regex matching is not supported on all OS's
   # Loop through each flow argument - for each flow in the arg list,
   # compare it to each flow found by mqsilist.  If you find a match,
   # set a flag.  After you've checked all the flow names in mqsilist,
   # if the flag is still off, this flow from the arg list is not 
   # configured, so add it to the list of erroneous flows. 
   for ARG in ${ARG_LIST} ; do
      DEBUG_LOG Checking \(${LIST_OF_FLOWS}\) for ${ARG}
      THIS_ONE_FOUND=0
      for LISTED_FLOW in ${LIST_OF_FLOWS} ; do
         if [ ${ARG} = ${LISTED_FLOW} ] ; then
            THIS_ONE_FOUND=1
         fi
      done
      if [ 0 -eq $THIS_ONE_FOUND ] ; then
         FLOWS_DONT_EXIST=${FLOWS_DONT_EXIST}' '${ARG}
      fi
   done
   
   MISSING_FLOWS=`echo ${FLOWS_DONT_EXIST} | wc -w`
   if [ ${MISSING_FLOWS} -ne 0 ]
   then
      echo 'Error: '${MISSING_FLOWS}' Message Flows do not exist: '${FLOWS_DONT_EXIST}
      DEBUG_LOG 'Error: '${MISSING_FLOWS}' Message Flows do not exist: '${FLOWS_DONT_EXIST}
      RC=194
      sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh MB_MESSAGE_FLOW_ERROR ${FLOWS_DONT_EXIST}
      exit $RC
   else 
      echo 'Found all flows: '${ARG_LIST} >> ${KD4_LOGDIR}/configMBDC.log
   fi
}       

#***************************************************************************
# Create directories under this broker name, and copy the lel file.
# If the LEL file already exists, it is overwritten, to upgrade it to the
#    current version
#***************************************************************************            
createFileSystem()
{
   #***************************************************************************
   #make directories for this broker
   #***************************************************************************            
   MBDC_MKDIR "${INSTALLDIR}/KD4/config/wmb"
   MBDC_MKDIR "${INSTALLDIR}/KD4/config/wmb/lib"
   MBDC_MKDIR "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME"
   MBDC_MKDIR "${INSTALLDIR}/KD4/config/wmb/config"
   MBDC_MKDIR "${INSTALLDIR}/KD4/config/wmb/config/$BROKER_NAME"
   
   #***************************************************************************
   #stop broker and copy lel to $SOA_EXIT_PATH
   #***************************************************************************
   echo "mqsistop ${BROKER_NAME}"
   DEBUG_LOG "mqsistop ${BROKER_NAME}"
   mqsistop  "$BROKER_NAME" 1>>${KD4_LOGDIR}/configMBDC.log
   
   if [ "$ACTION" = "-enable" ]
   then
      DEBUG_LOG cp -f "$INSTALLDIR/KD4/lib/$LEL_NAME" "$SOA_EXIT_PATH/$LEL_NAME"
      cp -f "$INSTALLDIR/KD4/lib/$LEL_NAME" "$SOA_EXIT_PATH/$LEL_NAME" 1>>$KD4_LOGDIR/configMBDC.log
      chmod 777 "$SOA_EXIT_PATH/$LEL_NAME" 1>>$KD4_LOGDIR/configMBDC.log
   fi
}

        
#***************************************************************************
# For each flow listed in ${MESSAGE_FLOW_NAME} (which is now a list IZ51644)
# create or delete the runflow file, as appropriate for $ACTION
#***************************************************************************            
manageRunflowFiles()
{
   for FLOW in ${MESSAGE_FLOW_NAME} ; do
      RUNNING_FLOW=${ACTIVE_FLOW_DIR}/${BROKER_NAME}.${EXECUTION_GROUP_NAME}.${FLOW}.runflow
      if [ "$ACTION" = "-enable" ]
      then
         MBDC_TOUCH "$RUNNING_FLOW"
      else
         MBDC_RM_FILE "$RUNNING_FLOW"
      fi
   done
}        

        
#***************************************************************************
# Update the user exit path for this $BROKER_NAME
#***************************************************************************            
setUserExitPath()
{
   #***************************************************************************
   # Get the old user exit path(s) 
   #***************************************************************************
   if [ -f /var/mqsi/registry/$BROKER_NAME/CurrentVersion/UserExitPath ]
   then
      OLD_MQSI_USER_EXIT_PATH=`cat /var/mqsi/registry/$BROKER_NAME/CurrentVersion/UserExitPath`
   fi
   echo "" ; echo "Old MQSI user exit path(s):$OLD_MQSI_USER_EXIT_PATH" ; echo ""
   DEBUG_LOG "Old MQSI user exit path(s):$OLD_MQSI_USER_EXIT_PATH"
   
   #***************************************************************************
   #judge $ACTION
   #***************************************************************************
   if [ "$ACTION" = "-enable" ]
   then
      #***************************************************************************
      #enable action
      #***************************************************************************
      echo "Add user exit path..." ; echo ""
      DEBUG_LOG "Add user exit path..."
       
      #***************************************************************************
      #get new MQSI_USER_EXIT_PATH
      #***************************************************************************
      echo $OLD_MQSI_USER_EXIT_PATH | grep $SOA_EXIT_PATH 1>>$KD4_LOGDIR/configMBDC.log 
      RC=$?
      if [ $RC -ne 0 ]
      then
         if [ $OLD_MQSI_USER_EXIT_PATH ]
         then
            NEW_MQSI_USER_EXIT_PATH=$OLD_MQSI_USER_EXIT_PATH:$SOA_EXIT_PATH
         else
            NEW_MQSI_USER_EXIT_PATH=$SOA_EXIT_PATH
         fi
         
         #***************************************************************************
         #change broker user exit path(s)
         #***************************************************************************
         MBDC_ChangeUserExitPath "$NEW_MQSI_USER_EXIT_PATH"        
      else
         NEW_MQSI_USER_EXIT_PATH=$OLD_MQSI_USER_EXIT_PATH
      fi      
      echo "New MQSI user exit path(s):$NEW_MQSI_USER_EXIT_PATH" ; echo ""
      DEBUG_LOG "New MQSI user exit path(s):$NEW_MQSI_USER_EXIT_PATH"
       
      
  #****************************************************************************
  # On a -disable, we don't want to remove the user exit path until
  #  all runflows are gone - we'll handle this after the user exit list
  #  has been adjusted
  #****************************************************************************
   
   fi
}
 
        
manageUserExitList()
{

   #***************************************************************************
   #start broker
   #***************************************************************************
   echo "mqsistart ${BROKER_NAME}"
   DEBUG_LOG "mqsistart ${BROKER_NAME}"
   mqsistart "$BROKER_NAME" 1>>${KD4_LOGDIR}/configMBDC.log 
   
   
   # Iterate all flow names
   for FLOW in ${MESSAGE_FLOW_NAME} ; do 
      echo "Updating user exit list for ${FLOW}"
      DEBUG_LOG "Updating user exit list for ${FLOW}"
            
      # List the current user exit list
      OLD_EXIT_LIST=`mqsireportflowuserexits $BROKER_NAME -e $EXECUTION_GROUP_NAME -f $FLOW | grep "BIP8856I" | awk '{print $NF}' | sed 's/\.$//'`
      echo "Existing exit list: ${OLD_EXIT_LIST}"
      DEBUG_LOG "Existing exit list: ${OLD_EXIT_LIST}"
      
      # Keep a flag if we had to change something
      DID_EXIT_LIST_CHANGE=
            
      if [ "$ACTION" = "-enable" ]
      then
         echo ":${OLD_EXIT_LIST}:"|grep :MqsiSOAExit: 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
         RC=$?
         if [ $RC -ne 0 ]
         then
            # Our exit was not already there
            if [ $OLD_EXIT_LIST ]
            then
               NEW_EXIT_LIST=$OLD_EXIT_LIST:MqsiSOAExit
            else
               NEW_EXIT_LIST=MqsiSOAExit
            fi
            DID_EXIT_LIST_CHANGE=Y
            echo "New exit list: ${NEW_EXIT_LIST}"
            DEBUG_LOG "New exit list: ${NEW_EXIT_LIST}"
         else
            # Our exit was already there
            DEBUG_LOG "MqsiSOAExit already exists, no need to add it."
            NEW_EXIT_LIST=
         fi
      else
         # action=-disable
         echo ":${OLD_EXIT_LIST}:"|grep :MqsiSOAExit: 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
         RC=$?
         if [ $RC -eq 0 ]
         then
            # Our exit was already there
            #***************************************************************************
            # Uninstall program needs to delete MqsiSOAExit from the Message Flow.
            #
            # example1: delete "c" from "c:b:f"
            #           step 1: add ":" to "c:b:f". to ensure that our exit name
            #                   is surrounded by colons ":c:b:f:"
            #           step 2: replace ":c:" with ":" in ":c:b:f:". ":b:f:"
            #           step 3: remove the prefix and postfix colons
            #***************************************************************************
            PREFIXED_OLD_EXIT_LIST=:$OLD_EXIT_LIST:
            NEW_EXIT_LIST=`echo $PREFIXED_OLD_EXIT_LIST|sed -e 's:\:MqsiSOAExit\::\::g'`
            NEW_EXIT_LIST=`echo $NEW_EXIT_LIST|sed "s/^.//;s/.$//"`
            echo "New exit list: ${NEW_EXIT_LIST}"
            DEBUG_LOG "New exit list: ${NEW_EXIT_LIST}"
            DID_EXIT_LIST_CHANGE=Y
         else
            # Our exit was not already there
            DEBUG_LOG "MqsiSOAExit is not on the list, no need to remove it."
            NEW_EXIT_LIST=
         fi
      fi
      # By now, NEW_EXIT_LIST contains the new list, whether we've been added or removed
      # change new user exit lists
      if [ ${DID_EXIT_LIST_CHANGE} ]
      then
         DEBUG_LOG mqsichangeflowuserexits "$BROKER_NAME" -e "$EXECUTION_GROUP_NAME" -f "$FLOW" -a "$NEW_EXIT_LIST"
         mqsichangeflowuserexits "$BROKER_NAME" -e "$EXECUTION_GROUP_NAME" -f "$FLOW" -a "$NEW_EXIT_LIST" 1>>$KD4_LOGDIR/configMBDC.log 
         echo "Exit list for ${FLOW} has been changed to ${NEW_EXIT_LIST}"
      else
         DEBUG_LOG "The exit list was not changed, no need to issue mqsichangeflowuserexits"
      fi
   done
}        
     
     
removeLELFile()
{
  if [ "$ACTION" = "-disable" ] 
  then
      #****************************************************************************
      # judge the disable flow if a last one. if is delete user exit path and lel
      #****************************************************************************
      DEBUG_LOG ls $ACTIVE_FLOW_DIR/*.runflow
      ls $ACTIVE_FLOW_DIR/*.runflow 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
      RC=$?
      if [ $RC -ne 0 ]
      then
         # rc!=0 means that no runflow files exist
         echo "No runflow files exist;  removing the ITCAM for SOA library from the exit path" ; echo ""
         DEBUG_LOG "No runflow files exist;  removing the ITCAM for SOA library from the exit path."
         
         echo "mqsistop ${BROKER_NAME}"
         DEBUG_LOG "mqsistop ${BROKER_NAME}"
         mqsistop  "$BROKER_NAME" 1>>${KD4_LOGDIR}/configMBDC.log
   
         #***************************************************************************
         # Unistall program need delete INPUT_USER_EXIT_PATH from the old user exit path.
         #
         # example1: delete "/c" from "/c:/b:/f"
         #           step 1: add ":" to "/c:/b:f". ":/c:/b:/f:"
         #           step 2: replace ":/c:" to ":" in ":/c:/b:/f:". ":/b:/f:"
         #           step 3: delete two ":" at head and tail. "/b:/f"
         #***************************************************************************
         PRE_MQSI_USER_EXIT_PATH=:$OLD_MQSI_USER_EXIT_PATH:
         NEW_MQSI_USER_EXIT_PATH=`echo $PRE_MQSI_USER_EXIT_PATH|sed -e 's:\:'$SOA_EXIT_PATH'\::\::g'`
         NEW_MQSI_USER_EXIT_PATH=`echo $NEW_MQSI_USER_EXIT_PATH|sed "s/^.//;s/.$//" 2>/dev/null`
         
         MBDC_ChangeUserExitPath "$NEW_MQSI_USER_EXIT_PATH"

         MBDC_RM_FILE $SOA_EXIT_PATH/$LEL_NAME

         MBDC_RM_DIR "$SOA_EXIT_PATH"
         MBDC_RM_DIR "$ACTIVE_FLOW_DIR"
         
         echo "The ITCAM for SOA user exit has been removed from all flows on ${BROKER_NAME}.  The broker was left in stopped state."
         DEBUG_LOG "The ITCAM for SOA user exit has been removed from all flows on ${BROKER_NAME}.  The broker was left in stopped state."
      fi    
  fi
}
        
       
UNIX_LINUX_configMBDC()
{  
   #***  IZ51644 check args in a subroutine
   #***  Starts broker and leaves it started
   validateParms
      
   #*** IZ51644 set up files and directories for this broker
   #*** Stops the broker and leaves it stopped
   createFileSystem                                
                         
   #*** IZ51644 create or delete runflow files
   manageRunflowFiles
   
   #*** IZ51644 Set the user exit path
   #*** Starts the broker and leaves it started
   setUserExitPath
   
   #*** Manage the user exit list for each flow
   manageUserExitList
   
   #*** Remove the LEL file if necessary
   removeLELFile
     
}

ZOS_enable_configMBDC()
{
   echo ""; echo "Begin to enable broker $BROKER_NAME ..." ; echo ""
   DEBUG_LOG "Begin to enable broker $BROKER_NAME .."
   
   #***************************************************************************
   #make make WMB runtime directory and copy lel to it
   #***************************************************************************
   if [ ! -d "${INSTALLDIR}/KD4/config/wmb" ]
   then
      mkdir -p "${INSTALLDIR}/KD4/config/wmb"
      chmod 777 "${INSTALLDIR}/KD4/config/wmb"
   fi
   
   if [ ! -d "${INSTALLDIR}/KD4/config/wmb/lib" ]
   then
      mkdir -p "${INSTALLDIR}/KD4/config/wmb/lib"
      chmod 777 "${INSTALLDIR}/KD4/config/wmb/lib"
   fi
   
   if [ ! -d "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME" ]
   then
      mkdir -p "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME"
      chmod 777 "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME"
   fi
   
   cp -f "$INSTALLDIR/KD4/lib/$LEL_NAME" "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
   chmod 777 "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME" 1>>$KD4_LOGDIR/configMBDC.log 2>>$KD4_LOGDIR/configMBDC.log
   
   echo "Copying the mqsisoauserexit.lel file from"
   echo "${INSTALLDIR}/KD4/lib directory to the"
   echo "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME directory."   
   echo ""
   echo "Copying file for $BROKER_NAME is finished."
   echo ""
   echo "Please refer to the product documentation for additional configuration steps"
   echo "for enabling and disabling data collection for the Message Broker environment."
   echo ""
   
   DEBUG_LOG "Copying the mqsisoauserexit.lel file from"
   DEBUG_LOG "${INSTALLDIR}/KD4/lib directory to the"
   DEBUG_LOG "${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME directory."
   DEBUG_LOG ""
   DEBUG_LOG "Copying file for $BROKER_NAME is finished."
   DEBUG_LOG ""
   DEBUG_LOG "Please refer to the product documentation for additional configuration steps"
   DEBUG_LOG "for enabling and disabling data collection for the Message Broker environment."
   DEBUG_LOG ""
}

ZOS_disable_configMBDC()
{
   echo ""; echo "Disabling broker $BROKER_NAME ..." ; echo ""
   DEBUG_LOG  "Disabling broker $BROKER_NAME ..."
   
   echo "The mqsisoauserexit.lel file is under ${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME"
   echo ""
   echo "Disable for broker $BROKER_NAME completed successfully."
   echo ""
   echo "Please refer to the product documentation for additional configuration steps"
   echo "for enabling and disabling data collection for the Message Broker environment."
   echo ""
   
   DEBUG_LOG "The mqsisoauserexit.lel file is under ${INSTALLDIR}/KD4/config/wmb/lib/$BROKER_NAME"
   DEBUG_LOG ""
   DEBUG_LOG "Disable for broker $BROKER_NAME completed successfully."
   DEBUG_LOG ""
   DEBUG_LOG "Please refer to the product documentation for additional configuration steps"
   DEBUG_LOG "for enabling and disabling data collection for the Message Broker environment."
   DEBUG_LOG ""
}

get_Last_Part_FileName()
{
   echo $1 | awk -F/ '{print $NF}'
}


######################## mainline ######################

ACTION=$1
BROKER_NAME=$2
EXECUTION_GROUP_NAME=$3
MESSAGE_FLOW_NAME=$4
LEL_NAME=mqsisoauserexit.lel
RC=0

EndOfFileName=`get_Last_Part_FileName ${INSTALLDIR}`

if [ "$EndOfFileName" = "" ] 
then
   SOA_EXIT_PATH=${INSTALLDIR}KD4/config/wmb/lib/${BROKER_NAME}
   ACTIVE_FLOW_DIR=${INSTALLDIR}KD4/config/wmb/config/${BROKER_NAME}
   KD4_LOGDIR=${INSTALLDIR}KD4/logs
else
   SOA_EXIT_PATH=${INSTALLDIR}/KD4/config/wmb/lib/${BROKER_NAME}
   ACTIVE_FLOW_DIR=${INSTALLDIR}/KD4/config/wmb/config/${BROKER_NAME}
   KD4_LOGDIR=${INSTALLDIR}/KD4/logs
fi



if [ ! -d ${KD4_LOGDIR} ]
then
   echo Error: KD4_LOGDIR ${KD4_LOGDIR} can not be found
   RC=195
   sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh MB_KD4_LOG_ERROR ${KD4_LOGDIR}
   exit $RC
fi

touch $KD4_LOGDIR/configMBDC.log 1>>/dev/null 2>>/dev/null

DEBUG_LOG
DEBUG_LOG =================Begin configMBDC=================
DEBUG_LOG cmd=sh $0 $*
RC=0
OS_NAME=`uname`
if [ "$OS_NAME" = "OS/390" ]
then
   #Z/OS
   echo ""; echo "Current OS is `uname`..." ; echo ""   
   DEBUG_LOG Current OS is `uname`...
   
   if [ "$ACTION" = "-enable" ]
   then
      ZOS_enable_configMBDC;   
   elif [ "$ACTION" = "-disable" ]
   then
      ZOS_disable_configMBDC;
   else
     echo Error: $ACTION is not [-enable|-disable]
     DEBUG_LOG Error: $ACTION is not [-enable|-disable]
     RC=191
     sh $INSTALLDIR/KD4/bin/WriteErrorFile.sh MB_ACTION_ERROR $ACTION
     exit $RC
   fi
elif [ "$OS_NAME" = "Linux" -o "$OS_NAME" = "AIX" -o "$OS_NAME" = "HP-UX" -o "$OS_NAME" = "SunOS" ]
then
   #Unix/Linux machine
   echo ""; echo "Current OS is `uname`..." ; echo ""
   DEBUG_LOG Current OS is `uname`
   
   UNIX_LINUX_configMBDC;
else
	echo ""; echo "Current OS is `uname`.  It is not supported." ; echo ""
	DEBUG_LOG Current OS is `uname`.  It is not supported.
        # Exit with a return code if there is an error.
        exit 1
fi

DEBUG_LOG =================End configMBDC=================

# If we have gotten this far, there was no error.
exit 0
